@@ -1,2 +1,2 @@
-from .conn import conn_db
+from .db import conn
 from ssdb import Client as DbClient
